==> circuit_synth-0.7.2.tar.gz: circuit_synth-0.7.2/src/circuit_synth/pcb/placement/spiral_placement.py <==
"""
Spiral placement algorithm for PCB components.

Note: Simplified version without dependencies on removed kicad_api.pcb module.
"""

import math
from dataclasses import dataclass
from typing import Dict, List, Any, Optional


@dataclass
class PlacementResult:
    """Result of a placement operation."""
    
    success: bool
    x: float = 0.0
    y: float = 0.0
    rotation: float = 0.0


class SpiralPlacer:
    """
    Spiral search pattern for finding valid component positions.
    
    Simplified implementation without dependencies on removed kicad_api.pcb modules.
    """
    
    def __init__(self, center_x: float = 0.0, center_y: float = 0.0):
        self.center_x = center_x
        self.center_y = center_y
    
    def find_placement(
        self, 
        component: Any, 
        existing_components: List[Any],
        max_radius: float = 100.0
    ) -> PlacementResult:
        """
        Find a valid placement position using spiral search.
        
        Stub implementation.
        """
        # Simple spiral placement algorithm stub
        angle_step = 15  # degrees
        radius_step = 5.0  # mm
        
        for radius in range(0, int(max_radius), int(radius_step)):
            for angle_deg in range(0, 360, angle_step):
                angle_rad = math.radians(angle_deg)
                x = self.center_x + radius * math.cos(angle_rad)
                y = self.center_y + radius * math.sin(angle_rad)
                
                # In a real implementation, we would check for collisions here
                # For now, just return the first position
                return PlacementResult(success=True, x=x, y=y)
        
        return PlacementResult(success=False)
    
    def place_components(self, components: List[Any]) -> Dict[str, PlacementResult]:
        """
        Place multiple components using spiral algorithm.
        
        Stub implementation.
        """
        results = {}
        placed_components = []
        
        for i, component in enumerate(components):
            result = self.find_placement(component, placed_components)
            component_id = f"component_{i}"
            results[component_id] = result
            if result.success:
                placed_components.append(component)
        
        return results

==> circuit_synth-0.8.31.tar.gz: circuit_synth-0.8.31/src/circuit_synth/pcb/placement/spiral_placement.py <==
"""
Spiral placement algorithm for PCB components.

Note: Simplified version without dependencies on removed kicad_api.pcb module.
"""

import math
from dataclasses import dataclass
from typing import Any, Dict, List, Optional


@dataclass
class PlacementResult:
    """Result of a placement operation."""

    success: bool
    x: float = 0.0
    y: float = 0.0
    rotation: float = 0.0


class SpiralPlacer:
    """
    Spiral search pattern for finding valid component positions.

    Simplified implementation without dependencies on removed kicad_api.pcb modules.
    """

    def __init__(self, center_x: float = 0.0, center_y: float = 0.0):
        self.center_x = center_x
        self.center_y = center_y

    def find_placement(
        self, component: Any, existing_components: List[Any], max_radius: float = 100.0
    ) -> PlacementResult:
        """
        Find a valid placement position using spiral search.

        Stub implementation.
        """
        # Simple spiral placement algorithm stub
        angle_step = 15  # degrees
        radius_step = 5.0  # mm

        for radius in range(0, int(max_radius), int(radius_step)):
            for angle_deg in range(0, 360, angle_step):
                angle_rad = math.radians(angle_deg)
                x = self.center_x + radius * math.cos(angle_rad)
                y = self.center_y + radius * math.sin(angle_rad)

                # In a real implementation, we would check for collisions here
                # For now, just return the first position
                return PlacementResult(success=True, x=x, y=y)

        return PlacementResult(success=False)

    def place_components(self, components: List[Any]) -> Dict[str, PlacementResult]:
        """
        Place multiple components using spiral algorithm.

        Stub implementation.
        """
        results = {}
        placed_components = []

        for i, component in enumerate(components):
            result = self.find_placement(component, placed_components)
            component_id = f"component_{i}"
            results[component_id] = result
            if result.success:
                placed_components.append(component)

        return results
